@@ -12,14 +12,21 @@ def tagging_vocabulary_factory(context):
     try:
         registry = getUtility(IRegistry)
         settings = registry.forInterface(ITagHelperSettingsSchema)
-        if settings.alchemy_api_key:
-            items.append(('alchemy', u'AlchemyAPI'))
-        if settings.yahoo_api_key:
-            items.append(('yahoo', u'Yahoo'))
-        if settings.calais_api_key:
-            items.append(('calais', u'Open Calais'))
         if settings.silcc_url:
             items.append(('silcc', u'SiLLC'))
-    except KeyError:
-        return SimpleVocabulary.fromItems([])
+        if settings.yahoo_api_key:
+            items.append(('yahoo', u'Yahoo'))
+        if settings.alchemy_api_key:
+            items.append(('alchemy', u'AlchemyAPI'))
+        if settings.calais_api_key:
+            items.append(('calais', u'Open Calais'))
+        if settings.zemanta_api_key:
+            items.append(('zemanta', u'Zemanta'))
+        if settings.openamplify_api_key:
+            items.append(('openamplify', u'OpenAmplify'))
+        if settings.evri_api_key:
+            items.append(('evri', u'Evri'))
+
+    except (KeyError, AttributeError):
+        return SimpleVocabulary.fromItems(items)
     return SimpleVocabulary.fromItems(items)
